@@ -375,11 +375,14 @@ WVoxBase::setupWidgets()
   QVBox       *VBoxBase = new QVBox(this);
   QWidget     *WidgetMisc = new QWidget(VBoxBase);
   QHBoxLayout *HBoxLayout = new QHBoxLayout(WidgetMisc);
+  QLabel      *LabelPosition = new QLabel("&Master Position (MM:SS)", WidgetMisc);
+  HBoxLayout->addWidget(LabelPosition);
   TimeEditPosition = new QTimeEdit(WidgetMisc);
   TimeEditPosition->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
   connect(TimeEditPosition, SIGNAL(valueChanged(const QTime&)),
-          this, SIGNAL(positionChanged(const QTime&)));
+          this, SIGNAL(masterPositionChanged(const QTime&)));
   HBoxLayout->addWidget(TimeEditPosition);
+  LabelPosition->setBuddy(TimeEditPosition);
   TimeEditPosition->setDisplay(
       QTimeEdit::Minutes | QTimeEdit::Seconds);
   HBoxLayout->addStretch();
