@@ -51,6 +51,11 @@ public:
   //! \param WidgetParent ƥåȤؤΥݥ󥿡
   //! \param cName åȤ̾Ρ
   WVoxStorm(QWidget* WidgetParent=0, const char *cName=0);
+  //! \brief 󥹥ȥ饯
+  //! \param strFileName VoxStormåե̾Ρ
+  //! \param WidgetParent ƥåȤؤΥݥ󥿡
+  //! \param cName åȤ̾Ρ
+  WVoxStorm(const QString& strFileName, QWidget* WidgetParent=0, const char *cName=0);
   //! \brief ǥȥ饯
   ~WVoxStorm();
 
@@ -66,6 +71,8 @@ protected:
 private:
   //! ȥåץ٥Υᥤ󥦥åȡ
   WVoxBase    *VoxBase;
+  //! ơСΤᡣ
+  QLabel      *LabelStatusBar;
   //! Vox Stormåե̾Ρ
   QString      strSessionFile;
   //! Ecasound-IAޥ͡㡣
@@ -85,6 +92,8 @@ private:
   //! ƥե饰
   bool         bDirty;
 
+  //! \brief ŪʽԤ
+  void initialize();
   //! \brief νԤ
   void setupActions();
   //! \brief ơСνԤ
