@@ -108,7 +108,7 @@ WVoxTrack::setupWidgets()
   IntNumInputLevel->setRange(0, 600);
   IntNumInputLevel->setValue(100);  // 100 %
 
-  LabelPan = new QLabel("Pan", VBoxValue);
+  LabelPan = new QLabel("Pan (center : 50)", VBoxValue);
   
   IntNumInputPan = new KIntNumInput(VBoxValue);
   IntNumInputPan->setRange(0, 100);
@@ -117,7 +117,7 @@ WVoxTrack::setupWidgets()
   HBoxButtonBase = new QHBox(VBoxController);
 
   // HBoxButtonBase has FileChooserTrack, WidgetSpacer, ColorButtonMute, ColorButtonRec
-  FileChooserTrack = new WFileChooser("", HBoxButtonBase);
+  FileChooserTrack = new WFileChooser("", "Detect sound source file", HBoxButtonBase);
   FileChooserTrack->setFileType("*.wav *.mp3|Sound files (*.wav; *.mp3)\n*"
                                 "|All files (*)");
 
